@@ -250,7 +250,7 @@ gcry_cipher_lookup_oid (const char *oid)
    and a pointer representhing this module is stored in MODULE.  */
 gcry_error_t
 gcry_cipher_register (gcry_cipher_spec_t *cipher,
-		      unsigned int *algorithm_id,
+		      int *algorithm_id,
 		      gcry_module_t *module)
 {
   gcry_err_code_t err = 0;
@@ -792,23 +792,29 @@ do_cbc_encrypt( gcry_cipher_hd_t c, byte *outbuf, const byte *inbuf,
 
     if ((c->flags & GCRY_CIPHER_CBC_CTS) && nbytes > blocksize)
       {
+	/* We have to be careful here, since outbuf might be equal to
+	   inbuf.  */
+
 	int restbytes;
+	byte b;
 
 	if ((nbytes % blocksize) == 0)
 	  restbytes = blocksize;
 	else
 	  restbytes = nbytes % blocksize;
 
-	memcpy(outbuf, outbuf - c->cipher->blocksize, restbytes);
-	outbuf -= c->cipher->blocksize;
+	outbuf -= blocksize;
+	for (ivp = c->iv, i = 0; i < restbytes; i++)
+	  {
+	    b = inbuf[i];
+	    outbuf[blocksize + i] = outbuf[i];
+	    outbuf[i] = b ^ *ivp++;
+	  }
+	for (; i < blocksize; i++)
+	  outbuf[i] = 0 ^ *ivp++;
 
-	for(ivp=c->iv,i=0; i < restbytes; i++ )
-	    outbuf[i] = inbuf[i] ^ *ivp++;
-	for(; i < blocksize; i++ )
-	    outbuf[i] = 0 ^ *ivp++;
-
-	c->cipher->encrypt ( &c->context.c, outbuf, outbuf );
-	memcpy(c->iv, outbuf, blocksize );
+	c->cipher->encrypt (&c->context.c, outbuf, outbuf);
+	memcpy (c->iv, outbuf, blocksize);
       }
 }
 
@@ -1063,8 +1069,8 @@ cipher_encrypt (gcry_cipher_hd_t c, byte *outbuf,
  * been requested.
  */
 gcry_error_t
-gcry_cipher_encrypt (gcry_cipher_hd_t h, byte *out, size_t outsize,
-                     const byte *in, size_t inlen)
+gcry_cipher_encrypt (gcry_cipher_hd_t h, void *out, size_t outsize,
+                     const void *in, size_t inlen)
 {
   gcry_err_code_t err;
 
@@ -1145,8 +1151,8 @@ cipher_decrypt (gcry_cipher_hd_t c, byte *outbuf, const byte *inbuf,
 
 
 gcry_error_t
-gcry_cipher_decrypt (gcry_cipher_hd_t h, byte *out, size_t outsize,
-		     const byte  *in, size_t inlen)
+gcry_cipher_decrypt (gcry_cipher_hd_t h, void *out, size_t outsize,
+		     const void *in, size_t inlen)
 {
   gcry_err_code_t err = GPG_ERR_NO_ERROR;
 
