@@ -53,6 +53,7 @@ static struct pubkey_table_entry
 #endif
 #if USE_ELGAMAL
     { &_gcry_pubkey_spec_elg, GCRY_PK_ELG },
+    { &_gcry_pubkey_spec_elg, GCRY_PK_ELG_E },
 #endif
 #if USE_DSA
     { &_gcry_pubkey_spec_dsa, GCRY_PK_DSA },
@@ -1206,12 +1207,14 @@ sexp_data_to_mpi (gcry_sexp_t input, unsigned int nbits, gcry_mpi_t *ret_mpi,
               if (!k)
                 break; /* Okay: no (more) zero bytes. */
               
-              k += k/128; /* Better get some more. */
+              k += k/128 + 3; /* Better get some more. */
               pp = gcry_random_bytes_secure (k, GCRY_STRONG_RANDOM);
-              for (j=0; j < i && k; j++)
+              for (j=0; j < i && k;)
                 {
                   if (!p[j])
                     p[j] = pp[--k];
+                  if (p[j])
+                    j++;
                 }
               gcry_free (pp);
             }
@@ -1665,7 +1668,10 @@ gcry_pk_sign (gcry_sexp_t *r_sig, gcry_sexp_t s_hash, gcry_sexp_t s_skey)
     mpi_free (hash);
 
   if (result)
-    gcry_free (result);
+    {
+      release_mpi_array (result);
+      gcry_free (result);
+    }
 
   return gcry_error (rc);
 }
@@ -2082,11 +2088,13 @@ gcry_pk_get_keygrip (gcry_sexp_t key, unsigned char *array)
 
   /* Check that the first element is valid. */
   list = gcry_sexp_find_token (key, "public-key", 0);
-  if (! list)
+  if (!list)
     list = gcry_sexp_find_token (key, "private-key", 0);
-  if (! list)
+  if (!list)
     list = gcry_sexp_find_token (key, "protected-private-key", 0);
-  if (! list)
+  if (!list)
+    list = gcry_sexp_find_token (key, "shadowed-private-key", 0);
+  if (!list)
     return NULL; /* No public- or private-key object. */
 
   l2 = gcry_sexp_cadr (list);
